# **TerCol**

#### _A completely useless library for terminal styling._

## **Why should I use this for terminal styling?**

- Sometimes, you will feel like you're insane and would wanna hit your head on the table multiple times. So, TerCol's there if that happens.

## **What features does this library have?**

- Everything other libraries have, except for rainbowtext() which is a unique feature this library has.

## **How do I use this?**

```python
import tercol

print(tercol.red('Red text'))
print(tercol.blue('Blue text'))
print(tercol.rgb(255, 215, 0, 'Gold text using RGB'))
print(tercol.hex('#ffd700', 'Gold text using HEX'))
print(tercol.rainbowtext('Rainbow text!'))

# it's that simple.
```

maybe try running this too at the terminal
```
py -m tercol
```

that's all
bye